
|函数|描述|示例|
|:--:|:--:|:--:|
|year(X, ZoneOffset)|取给定时间的年份<br>第1个参数为Unix epoch timestamp [13位，毫秒级时间戳]；同时该函数具备一定的时间日期解析功能，对于"2019-08-01T07:30:45.123+0800"的日期时间格式（ISO 8601），可以直接解析，也可作为第1个参数。<br>第2个参数（可选）为表示时区的整数，e.g. 8表示东八区，-7表示西七区。|eval v=year(_time)<br>eval v=year("2019-08-01")<br>eval v=year("2019-08-01T07:30:45")<br>eval v=year("2019-08-01T07:30:45.123")<br>eval v=year("2019-08-01T07:30:45.123456789")<br>eval v=year("2019-08-01T07:30:45.123456789+0800")<br>eval v=year(_time, 7)|
|month(X, ZoneOffset)|取给定时间的月份<br>参数同 year 函数|eval v=month(_time)<br>eval v=month("2019-08-01")<br>eval v=month("2019-08-01T07:30:45")<br>eval v=month("2019-08-01T07:30:45.123")<br>eval v=month(_time, 7)|
|day(X, ZoneOffset)|取给定时间在当前月份的第几天<br>参数同year函数|eval v=day(_time)|
|week(X, ZoneOffset)|取给定时间的在当前年的第几周<br>参数规格同year函数|eval v=week(_time)|
|hour(X, ZoneOffset)|取给定时间的小时<br>参数同year函数|eval v=hour(_time)|
|minute(X, ZoneOffset)|取给定时间的分钟<br>参数同year函数|eval v=minute(_time)|
|second(X, ZoneOffset)|取给定时间的秒数<br>参数同year函数|eval v=second(_time)|
|isWeekday(X, ZoneOffset)|判断当天是否是工作日，返回bool结果<br>参数同year函数|eval v=isWeekday(_time)|
|isWeekend(X, ZoneOffset)|判断当前是否是周末<br>参数同year函数|eval v=isWeekend(_time)|
|datediff(X, Y, TimeUnit)|计算时间差，接受2个或3个参数<br>参数1和参数2既可以是13位的毫秒级时间戳也可以是形如"2019-08-01"的ISO 8601日期时间格式的字符串<br>参数3（可选），用于指定函数计算结果的时间单位。可选值有（注：使用双引号而非单引号）："s", "m", "h", "d". 若没有指定该参数，则返回值是毫秒级的时间差。|eval v=datediff(time1, time2)<br>eval v=datediff(1563429270000, 1563342870000)<br>eval v =datediff("2019-09-02", "2019-09-01")<br>eval v=datediff(1563429270000, 1563342870000, "d")|
|nextWeekday(X, Y, ZoneOffset)|返回下个工作日的时间，接受1~3个参数<br>参数1既可以是13位的毫秒级时间戳也可以是形如"2019-08-01"的ISO 8601日期时间格式的字符串<br>参数2（可选），表示从参数1的日期算起，第Y个工作日<br>参数3（可选），表示时区的整数，e.g. 8表示东八区，-7表示西七区。|eval t=nextWeekday(_time)<br>eval t=nextWeekday(now())<br>eval t=nextWeekday("2019-08-01")<br>eval t=nextWeekday("2019-08-01", 4)<br>eval t=nextWeekday("2019-08-01", 4, 7)|
|relativeTime(X, Y)|返回相对时间（毫秒级时间戳）<br>接受2个参数<br>参数1：时间基准。既可以是13位的毫秒级时间戳也可以是形如"2019-08-01"的ISO 8601日期时间格式的字符串。<br>参数2：相对时间指示符。e.g. "-2d@d+3h"表示两天前，时间对齐到天，最后再向前偏移2小时。相对时间指示符可参考：[相对时间语法快速入门](?id=search)|eval t=relativeTime(now(), "-3d@d")|
|now|返回当前的毫秒精度时间戳|eval n=now()|
|isHoliday(X, ZoneOffset)|判断当天是否是国家法定节假日，返回bool结果<br>参数同year函数|eval v=isHoliday(_time)|
|isWorkingDay(X, ZoneOffset)|判断当天是否是上班日，返回bool结果<br>参数同year函数|eval v=isWorkingDay(_time)|
|lastWorkingDay(X, ZoneOffset)|返回上一个上班日时间<br>参数同year函数|eval v=lastWorkingDay(_time)|
|nextWorkingDay(X, ZoneOffset)|返回下一个上班日时间<br>参数同year函数|eval v=nextWorkingDay(_time)|
|betweenWorkingDay(X, Y, ZoneOffset)|计算两个时间之间的上班日数，闭区间，接受2~3个参数<br>参数1和参数2既可以是13位的毫秒级时间戳也可以是形如"2019-08-01"的ISO 8601日期时间格式的字符串<br>参数3（可选），表示时区的整数，e.g. 8表示东八区，-7表示西七区。|eval v=betweenWorkingDay(2019-10-01",2019-10-10")|
|isTradingDay(X, ZoneOffset)|判断当天是否是内地的证券交易所的交易日，返回bool结果<br>参数同year函数|eval v=isTradingDay(_time)|
|lastTradingDay(X, ZoneOffset)|返回上一个交易日时间<br>参数同year函数|eval v=lastTradingDay(_time)|
|nextTradingDay(X, ZoneOffset)|返回下一个交易日时间<br>参数同year函数|eval v=nextTradingDay(_time)|
|betweenTradingDay(X, Y, ZoneOffset)|计算两个时间之间的交易日数，闭区间<br>参数同betweenWorkingDay函数|eval v=betweenTradingDay(2019-10-01",2019-10-10")|
